@@ -61,6 +61,7 @@ class TagsBlock:
         self.line = line
         self.column = column
         self.members = members
+        self.known_tags = {}
 
     def __repr__(self):
         return 'TagsBlock { ' + str(self.members) + ' }'
@@ -123,3 +124,12 @@ class UsingTag:
         self.column = column
         self.from_name = from_name
         self.to_name = to_name
+
+class Group:
+    def __init__(self, line, column, body):
+        self.line = line
+        self.column = column
+        self.members = body
+
+    def __repr__(self):
+        return 'Group { ' + str(self.members) + ' }'
